import argparse
import sys
import csv
import urllib2

from settings import settings


def fetch_page(tec_id):
    return urllib2.urlopen('http://204.65.203.5/public/{0}noadd.csv'.format(str(tec_id)))


def prepare_rows(page):
    return csv.reader(page)


def get_data(filing_id, type, basic=False):
    page = fetch_page(filing_id)
    rows = prepare_rows(page)

    header_row = settings[type]['full_pull']['header']
    indexes = settings[type]['full_pull']['indexes']
    type_code = settings[type]['type_code']

    if basic:
        header_row = settings[type]['basic_pull']['header']
        indexes = settings[type]['basic_pull']['indexes']

    write_to = csv.writer(sys.stdout)
    write_to.writerow(header_row)

    for row in rows:
        if not row:
            continue

        if row[0] == type_code:
            row = [row[x] for x in indexes]

            write_to.writerow(row)


def main():
    parser = argparse.ArgumentParser()

    parser.add_argument('filing_id', help='TEC filing ID')
    parser.add_argument("-t", "--type",
                        help="The type of data you want to get",
                        choices=['contributions', 'expenditures'])
    parser.add_argument("-s", "--simple",
                        help='Return just the basic fields, good if you just want numbers',
                        action='store_true')
    args = parser.parse_args()

    if not args.type:
        parser.error('No data type provided, please supply a --type')

    basic_status = args.simple

    get_data(args.filing_id, args.type, basic_status)


if __name__ == '__main__':
    main()



settings = {
    'contributions': {
        'type_code': 'RCPT',
        'full_pull': {
            'indexes': range(36),
            'header': [
                'Record Type',
                'Name of Schedule',
                'Unique ID',
                'Entity Code',
                'Last/Organization Name',
                'First Name(s)',
                'Title',
                'Suffix',
                'Street Address 1',
                'Street Address 2',
                'City',
                'State',
                'ZIP Code',
                'Out-of-state PAC Check-box',
                'Out-of-state PAC FEC ID',
                'Date',
                'Amount/In-kind Value',
                'Description',
                'Employer',
                'Principal Occupation/Job Title',
                'Job Title',
                'Spouse Law firm of spouse',
                'Child Parent Law Firm 1',
                'Child Parent Law Firm 2',
                'Travel Outside Texas (If In-kind)',
                'Traveler Last Name (If in-kind)',
                'Traveler First Name(s)',
                'Traveler Title',
                'Traveler Suffix',
                'Means of Transport',
                'Name of Each Departure City/Location',
                'Departure Date',
                'Name of Each Destination City/Location',
                'Arrival Date in Destination City/Location',
                'Purpose of Travel',
                'Item_ID of Parent Record',
            ]
        },
        'basic_pull': {
            'indexes': [2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 15, 16, 17, 18, 19, 24],
            'header': [
                'Unique ID',
                'Entity Code',
                'Last/Organization Name',
                'First Name(s)',
                'Title',
                'Suffix',
                'Street Address 1',
                'Street Address 2',
                'City',
                'State',
                'ZIP Code',
                'Date',
                'Amount/In-kind Value',
                'Description',
                'Employer',
                'Principal Occupation/Job Title',
                'Travel Outside Texas (If In-kind)',
            ]
        }
    },
    'expenditures': {
    'type_code': 'EXPN',
        'full_pull': {
            'indexes': range(42),
            'header': [
                'Record Type',
                'Name of Schedule',
                'Unique ID ',
                'Entity Code',
                'Last/Organization Name',
                'First Name(s)',
                'Title',
                'Suffix',
                'Street Address 1',
                'Street Address 2',
                'City',
                'State',
                'ZIP Code',
                'Date',
                'Amount',
                'Description',
                'Expenditure is Contribution',
                'Reimbursement Intended ',
                'Candidate Last Name',
                'Candidate First Name(s)',
                'Candidate Title',
                'Candidate Suffix',
                'Office Held Code',
                'Office Held Description',
                'Office Held District',
                'Office Sought Code',
                'Office Sought Description',
                'Office Sought District',
                'Item_ID of Parent Record',
                'Expend from Corporate/Labor Contribution',
                'Travel Outside Texas',
                'Traveler Last Name',
                'Traveler First Name(s)',
                'Traveler Title',
                'Traveler Suffix',
                'Means of Transport',
                'Name of Each Departure City/Location',
                'Departure Date',
                'Name of Each Destination City/Location',
                'Arrival Date in Destination City/Location',
                'Purpose of Travel',
                'Item_ID of Parent Record (Travel)',
            ]
        },
        'basic_pull': {
            'indexes': [2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15],
            'header': [
                'Unique ID',
                'Entity Code',
                'Last/Organization Name',
                'First Name(s)',
                'Title',
                'Suffix',
                'Street Address 1',
                'Street Address 2',
                'City',
                'State',
                'ZIP Code',
                'Date',
                'Amount',
                'Description',
            ]
        }
    }
}



from setuptools import setup, find_packages


with open('README.rst') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

setup(
    name='tecfilingfetcher',
    version='0.0.1',
    description='A tool for processing raw filing files from the Texas Ethics Commission.',
    long_description=readme,
    author='Ryan Murphy',
    author_email='rmurphy@texastribune.org',
    url='https://github.com/rdmurphy/tecfilingfetcher',
    license=license,
    packages=find_packages(exclude=('tests', 'docs')),
    entry_points = {
      'console_scripts': [
          'fetchfiling = tecfilingfetcher.tecfilingfetcher:main',
        ]
    },
)
